@@ -1,3 +1,3 @@
 # -*- coding: utf-8 -*-
 from base import BW2Test
-from meta import DatabaseTest
+from database import DatabaseTest
